@@ -9,7 +9,7 @@
  *
  * @copyright &copy; 1999-2007 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: plugin.php 12127 2007-01-13 20:07:24Z kink $
+ * @version $Id: plugin.php 12752 2007-11-01 18:54:18Z pdontthink $
  * @package squirrelmail
  */
 
@@ -189,7 +189,11 @@ function soupNazi(){
 /*** MAIN PLUGIN LOADING CODE HERE ***/
 /*************************************/
 
-/* On startup, register all plugins configured for use. */
+/* On startup, register all plugins configured for use. 
+   $plugins needs to be globalized because this file is
+   sometimes included inside function (non-global) scope,
+   such as for logout_error. */
+global $plugins;
 if (isset($plugins) && is_array($plugins)) {
     // turn on output buffering in order to prevent output of new lines
     ob_start();
@@ -204,4 +208,4 @@ if (isset($plugins) && is_array($plugins)) {
     }
 }
 
-?>
\ No newline at end of file
+?>
