@@ -7,11 +7,14 @@
  *
  * @copyright &copy; 1999-2007 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: addressbook.php 12127 2007-01-13 20:07:24Z kink $
+ * @version $Id: addressbook.php 12537 2007-07-14 18:34:04Z kink $
  * @package squirrelmail
  * @subpackage addressbook
  */
 
+/** This is the addressbook page */
+define('PAGE_NAME', 'addressbook');
+
 /**
  * Path for SquirrelMail required files.
  * @ignore
