@@ -7,10 +7,13 @@
  *
  * @copyright &copy; 1999-2007 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: image.php 12127 2007-01-13 20:07:24Z kink $
+ * @version $Id: image.php 12537 2007-07-14 18:34:04Z kink $
  * @package squirrelmail
  */
 
+/** This is the image page */
+define('PAGE_NAME', 'image');
+
 /**
  * Path for SquirrelMail required files.
  * @ignore
