@@ -8,7 +8,7 @@
  *
  * @copyright &copy; 1999-2007 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: login.php 12614 2007-08-28 20:30:29Z pdontthink $
+ * @version $Id: login.php 12768 2007-11-19 04:20:34Z jangliss $
  * @package squirrelmail
  */
 
@@ -23,8 +23,6 @@ define('SM_PATH','../');
 
 /* SquirrelMail required files. */
 require_once(SM_PATH . 'functions/global.php');
-require_once(SM_PATH . 'functions/strings.php');
-require_once(SM_PATH . 'config/config.php');
 require_once(SM_PATH . 'functions/i18n.php');
 require_once(SM_PATH . 'functions/plugin.php');
 require_once(SM_PATH . 'functions/constants.php');
@@ -61,6 +59,51 @@ if (!empty($_SESSION)) {
     $_SESSION = array();
 }
 
+/**
+ * Allow administrators to define custom session handlers
+ * for SquirrelMail without needing to change anything in
+ * php.ini (application-level).
+ *
+ * In config_local.php, admin needs to put:
+ *
+ *     $custom_session_handlers = array(
+ *         'my_open_handler',
+ *         'my_close_handler',
+ *         'my_read_handler',
+ *         'my_write_handler',
+ *         'my_destroy_handler',
+ *         'my_gc_handler',
+ *     );
+ *     session_module_name('user');
+ *     session_set_save_handler(
+ *         $custom_session_handlers[0],
+ *         $custom_session_handlers[1],
+ *         $custom_session_handlers[2],
+ *         $custom_session_handlers[3],
+ *         $custom_session_handlers[4],
+ *         $custom_session_handlers[5]
+ *     );
+ * 
+ * We need to replicate that code once here because PHP has
+ * long had a bug that resets the session handler mechanism
+ * when the session data is also destroyed.  Because of this
+ * bug, even administrators who define custom session handlers
+ * via a PHP pre-load defined in php.ini (auto_prepend_file)
+ * will still need to define the $custom_session_handlers array 
+ * in config_local.php.
+ */
+global $custom_session_handlers;
+if (!empty($custom_session_handlers)) {
+    $open    = $custom_session_handlers[0];
+    $close   = $custom_session_handlers[1];
+    $read    = $custom_session_handlers[2];
+    $write   = $custom_session_handlers[3];
+    $destroy = $custom_session_handlers[4];
+    $gc      = $custom_session_handlers[5];
+    session_module_name('user');
+    session_set_save_handler($open, $close, $read, $write, $destroy, $gc);
+}
+
 /* put session_expired_* variables back in session */
 sqsession_is_active();
 if (!empty($sel)) {
