@@ -7,10 +7,13 @@
  *
  * @copyright &copy; 1999-2007 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: signout.php 12127 2007-01-13 20:07:24Z kink $
+ * @version $Id: signout.php 12537 2007-07-14 18:34:04Z kink $
  * @package squirrelmail
  */
 
+/** This is the signout page */
+define('PAGE_NAME', 'signout');
+
 /**
  * Path for SquirrelMail required files.
  * @ignore
@@ -63,7 +66,7 @@ set_up_language($squirrelmail_language, true, true);
 <?php
     if ($theme_css != '') {
 ?>
-   <link rel="stylesheet" type="text/css" href="<?php echo $theme_css; ?>" />
+   <link rel="stylesheet" type="text/css" href="<?php echo $theme_css; ?>">
 <?php
     }
 ?>
@@ -93,4 +96,4 @@ html_tag( 'table',
 'center', $color[4], 'width="50%" cols="1" cellpadding="2" cellspacing="0" border="0"' )
 ?>
 </body>
-</html>
\ No newline at end of file
+</html>
