@@ -7,7 +7,7 @@
  * @author Tyler Akins
  * @copyright &copy; 2001-2007 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: darkness.php 12304 2007-03-04 02:26:48Z jervfors $
+ * @version $Id: darkness.php 12602 2007-08-27 03:16:00Z jangliss $
  * @package squirrelmail
  * @subpackage themes
  */
@@ -42,9 +42,7 @@ function IsUnique($Distance, $r, $g, $b, $usedArray)
 // Always tremble background
 // This might make people go insane.  Yes!  *Victory dance!*
 function Darkness_HeaderPlugin() {
-   global $PHP_SELF;
-
-   if (substr($PHP_SELF, -18) == '/src/left_main.php') {
+   if (defined('PAGE_NAME') && PAGE_NAME=='left_main') {
       echo '<meta http-equiv="Page-Enter" content="' .
          'blendTrans(Duration=2.0)" />' . "\n";
    }
